@@ -1,5 +1,7 @@
 var NAVTREEINDEX28 =
 {
+"globals_func_o.html":[7,1,1,2],
+"globals_func_r.html":[7,1,1,3],
 "globals_func_s.html":[7,1,1,4],
 "globals_func_t.html":[7,1,1,5],
 "globals_func_u.html":[7,1,1,6],
