@@ -34,7 +34,6 @@ var dir_f6533bbb374262d299aa8b7962df9f04 =
     [ "AccessibleToolBox.idl", "AccessibleToolBox_8idl.html", "AccessibleToolBox_8idl" ],
     [ "AccessibleToolBoxItem.idl", "AccessibleToolBoxItem_8idl.html", "AccessibleToolBoxItem_8idl" ],
     [ "AccessibleTreeListBox.idl", "AccessibleTreeListBox_8idl.html", "AccessibleTreeListBox_8idl" ],
-    [ "AccessibleTreeListBoxEntry.idl", "AccessibleTreeListBoxEntry_8idl.html", "AccessibleTreeListBoxEntry_8idl" ],
     [ "AccessibleWindow.idl", "AccessibleWindow_8idl.html", "AccessibleWindow_8idl" ],
     [ "ActionEvent.idl", "ActionEvent_8idl.html", "ActionEvent_8idl" ],
     [ "AdjustmentEvent.idl", "AdjustmentEvent_8idl.html", "AdjustmentEvent_8idl" ],
@@ -300,7 +299,7 @@ var dir_f6533bbb374262d299aa8b7962df9f04 =
     [ "XVclContainerListener.idl", "XVclContainerListener_8idl.html", "XVclContainerListener_8idl" ],
     [ "XVclContainerPeer.idl", "XVclContainerPeer_8idl.html", "XVclContainerPeer_8idl" ],
     [ "XVclWindowPeer.idl", "XVclWindowPeer_8idl.html", "XVclWindowPeer_8idl" ],
-    [ "XView.idl", "awt_2XView_8idl.html", "awt_2XView_8idl" ],
+    [ "XView.idl", "XView_8idl.html", "XView_8idl" ],
     [ "XWindow.idl", "XWindow_8idl.html", "XWindow_8idl" ],
     [ "XWindow2.idl", "XWindow2_8idl.html", "XWindow2_8idl" ],
     [ "XWindowListener.idl", "XWindowListener_8idl.html", "XWindowListener_8idl" ],
